@@ -10,9 +10,20 @@ class EthCallBalanceOf(EthCall):
         data = encode_eth_call_balance_of(address)
         super().__init__(to=contract_address, data=data, block_number=block_number, id=id)
         self.type = "eth_call_balance_of"
+        self.address = address
 
     def set_result(self, result):
-        self.result = decode_eth_call_balance_of(result)
+        try:
+            self.result = decode_eth_call_balance_of(result)
+        except Exception as e:
+            print(f"""
+            EthCallBalanceOf set result err {e}
+            EthCallBalanceOf  result : {result}
+            EthCallBalanceOf id : {self.id}
+            EthCallBalanceOf smart contract : {self.to}
+            EthCallBalanceOf block number : {self.block_number}
+            EthCallBalanceOf address : {self.address}
+            """)
         return self.result
 
     def decode_result(self):
